@@ -1,6 +1,6 @@
 
 nullSim<- function(y,x,gdat,ped,gmap,ids,method=c("permutation","gene dropping"),
-   vc=NULL,intcovar=NULL,minorGenoFreq=0.05,rmv=TRUE,nit=25,ntimes=10){
+   vc=NULL,intcovar=NULL,test = c("None","F","Chisq"),minorGenoFreq=0.05,rmv=TRUE,ntimes=10){
    matr<- rep(NA,ntimes)
    method<- match.arg(method)
    if(method=="gene dropping"){
@@ -10,19 +10,19 @@ nullSim<- function(y,x,gdat,ped,gmap,ids,method=c("permutation","gene dropping")
             recode.pedigree=FALSE)
 
          llkTmp<- scanOne(y=y,x=x,gdat=gdatTmp,vc=vc,intcovar=intcovar,
-            minorGenoFreq=minorGenoFreq,rmv=rmv,nit=nit)
+            test=test,minorGenoFreq=minorGenoFreq,rmv=rmv)
          if(is.null(llkTmp)) next
 
-         matr[n]<- max(llkTmp$lr)
+         matr[n]<- max(llkTmp$p)
       }
    }else if(method=="permutation"){
       if(missing(gdat)) stop("gdat must be supplied.")
       idx<- sample(1:nrow(gdat),replace=FALSE)
       llkTmp<- scanOne(y=y,x=x,gdat=gdat[idx,],vc=vc,intcovar=intcovar,
-         minorGenoFreq=minorGenoFreq,rmv=rmv,nit=nit)
+         test=test,minorGenoFreq=minorGenoFreq,rmv=rmv)
       if(is.null(llkTmp)) next
 
-      matr[n]<- max(llkTmp$lr)
+      matr[n]<- max(llkTmp$p)
    }else stop("permutation or gene dropping.")
 
    matr
